# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

SNAKE_TO_CAMEL_CASE_TABLE = {
    "accepts_prompt_none_forward_from_client": "acceptsPromptNoneForwardFromClient",
    "access_code_lifespan": "accessCodeLifespan",
    "access_code_lifespan_login": "accessCodeLifespanLogin",
    "access_code_lifespan_user_action": "accessCodeLifespanUserAction",
    "access_token_lifespan": "accessTokenLifespan",
    "access_token_lifespan_for_implicit_flow": "accessTokenLifespanForImplicitFlow",
    "access_type": "accessType",
    "account_theme": "accountTheme",
    "action_token_generated_by_admin_lifespan": "actionTokenGeneratedByAdminLifespan",
    "action_token_generated_by_user_lifespan": "actionTokenGeneratedByUserLifespan",
    "add_read_token_role_on_create": "addReadTokenRoleOnCreate",
    "add_to_access_token": "addToAccessToken",
    "add_to_id_token": "addToIdToken",
    "add_to_userinfo": "addToUserinfo",
    "admin_events_details_enabled": "adminEventsDetailsEnabled",
    "admin_events_enabled": "adminEventsEnabled",
    "admin_theme": "adminTheme",
    "admin_url": "adminUrl",
    "aggregate_attributes": "aggregateAttributes",
    "always_read_value_from_ldap": "alwaysReadValueFromLdap",
    "assertion_consumer_post_url": "assertionConsumerPostUrl",
    "assertion_consumer_redirect_url": "assertionConsumerRedirectUrl",
    "attribute_friendly_name": "attributeFriendlyName",
    "attribute_name": "attributeName",
    "attribute_value": "attributeValue",
    "authenticate_by_default": "authenticateByDefault",
    "authentication_flow_binding_overrides": "authenticationFlowBindingOverrides",
    "authorization_idp_resource_id": "authorizationIdpResourceId",
    "authorization_resource_server_id": "authorizationResourceServerId",
    "authorization_token_exchange_scope_permission_id": "authorizationTokenExchangeScopePermissionId",
    "authorization_url": "authorizationUrl",
    "backchannel_supported": "backchannelSupported",
    "base_path": "basePath",
    "base_url": "baseUrl",
    "batch_size_for_sync": "batchSizeForSync",
    "bind_credential": "bindCredential",
    "bind_dn": "bindDn",
    "browser_flow": "browserFlow",
    "cache_policy": "cachePolicy",
    "changed_sync_period": "changedSyncPeriod",
    "claim_name": "claimName",
    "claim_value": "claimValue",
    "claim_value_type": "claimValueType",
    "client_authentication_flow": "clientAuthenticationFlow",
    "client_id": "clientId",
    "client_id_for_role_mappings": "clientIdForRoleMappings",
    "client_offline_session_idle_timeout": "clientOfflineSessionIdleTimeout",
    "client_offline_session_max_lifespan": "clientOfflineSessionMaxLifespan",
    "client_role_prefix": "clientRolePrefix",
    "client_scope_id": "clientScopeId",
    "client_secret": "clientSecret",
    "client_session_idle_timeout": "clientSessionIdleTimeout",
    "client_session_max_lifespan": "clientSessionMaxLifespan",
    "client_signature_required": "clientSignatureRequired",
    "client_timeout": "clientTimeout",
    "composite_roles": "compositeRoles",
    "configure_scope": "configureScope",
    "connection_timeout": "connectionTimeout",
    "connection_url": "connectionUrl",
    "consent_required": "consentRequired",
    "consent_screen_text": "consentScreenText",
    "custom_user_search_filter": "customUserSearchFilter",
    "day_month": "dayMonth",
    "day_month_end": "dayMonthEnd",
    "decision_strategy": "decisionStrategy",
    "default_action": "defaultAction",
    "default_default_client_scopes": "defaultDefaultClientScopes",
    "default_optional_client_scopes": "defaultOptionalClientScopes",
    "default_scopes": "defaultScopes",
    "default_signature_algorithm": "defaultSignatureAlgorithm",
    "direct_access_grants_enabled": "directAccessGrantsEnabled",
    "direct_grant_flow": "directGrantFlow",
    "disable_user_info": "disableUserInfo",
    "display_name": "displayName",
    "display_name_html": "displayNameHtml",
    "docker_authentication_flow": "dockerAuthenticationFlow",
    "drop_non_existing_groups_during_sync": "dropNonExistingGroupsDuringSync",
    "duplicate_emails_allowed": "duplicateEmailsAllowed",
    "edit_mode": "editMode",
    "edit_username_allowed": "editUsernameAllowed",
    "email_theme": "emailTheme",
    "email_verified": "emailVerified",
    "enabled_event_types": "enabledEventTypes",
    "encrypt_assertions": "encryptAssertions",
    "encryption_certificate": "encryptionCertificate",
    "events_enabled": "eventsEnabled",
    "events_expiration": "eventsExpiration",
    "events_listeners": "eventsListeners",
    "exclude_session_state_from_auth_response": "excludeSessionStateFromAuthResponse",
    "execution_id": "executionId",
    "extra_config": "extraConfig",
    "federated_identities": "federatedIdentities",
    "first_broker_login_flow_alias": "firstBrokerLoginFlowAlias",
    "first_name": "firstName",
    "force_authn": "forceAuthn",
    "force_name_id_format": "forceNameIdFormat",
    "force_post_binding": "forcePostBinding",
    "friendly_name": "friendlyName",
    "front_channel_logout": "frontChannelLogout",
    "full_path": "fullPath",
    "full_scope_allowed": "fullScopeAllowed",
    "full_sync_period": "fullSyncPeriod",
    "group_id": "groupId",
    "group_ids": "groupIds",
    "group_name_ldap_attribute": "groupNameLdapAttribute",
    "group_object_classes": "groupObjectClasses",
    "groups_claim": "groupsClaim",
    "groups_ldap_filter": "groupsLdapFilter",
    "groups_path": "groupsPath",
    "gui_order": "guiOrder",
    "hide_on_login_page": "hideOnLoginPage",
    "hosted_domain": "hostedDomain",
    "hour_end": "hourEnd",
    "icon_uri": "iconUri",
    "identity_provider_alias": "identityProviderAlias",
    "idp_initiated_sso_relay_state": "idpInitiatedSsoRelayState",
    "idp_initiated_sso_url_name": "idpInitiatedSsoUrlName",
    "ignore_missing_groups": "ignoreMissingGroups",
    "impersonate_scope": "impersonateScope",
    "implicit_flow_enabled": "implicitFlowEnabled",
    "import_enabled": "importEnabled",
    "include_authn_statement": "includeAuthnStatement",
    "include_in_token_scope": "includeInTokenScope",
    "included_client_audience": "includedClientAudience",
    "included_custom_audience": "includedCustomAudience",
    "initial_login": "initialLogin",
    "initial_password": "initialPassword",
    "internal_id": "internalId",
    "is_mandatory_in_ldap": "isMandatoryInLdap",
    "jwks_url": "jwksUrl",
    "last_name": "lastName",
    "ldap_attribute": "ldapAttribute",
    "ldap_full_name_attribute": "ldapFullNameAttribute",
    "ldap_groups_dn": "ldapGroupsDn",
    "ldap_password_policy_hints_enabled": "ldapPasswordPolicyHintsEnabled",
    "ldap_roles_dn": "ldapRolesDn",
    "ldap_user_federation_id": "ldapUserFederationId",
    "link_only": "linkOnly",
    "login_hint": "loginHint",
    "login_theme": "loginTheme",
    "login_with_email_allowed": "loginWithEmailAllowed",
    "logout_service_post_binding_url": "logoutServicePostBindingUrl",
    "logout_service_redirect_binding_url": "logoutServiceRedirectBindingUrl",
    "logout_url": "logoutUrl",
    "manage_group_membership_scope": "manageGroupMembershipScope",
    "manage_scope": "manageScope",
    "map_roles_client_scope_scope": "mapRolesClientScopeScope",
    "map_roles_composite_scope": "mapRolesCompositeScope",
    "map_roles_scope": "mapRolesScope",
    "mapped_group_attributes": "mappedGroupAttributes",
    "master_saml_processing_url": "masterSamlProcessingUrl",
    "memberof_ldap_attribute": "memberofLdapAttribute",
    "membership_attribute_type": "membershipAttributeType",
    "membership_ldap_attribute": "membershipLdapAttribute",
    "membership_user_ldap_attribute": "membershipUserLdapAttribute",
    "minute_end": "minuteEnd",
    "month_end": "monthEnd",
    "name_id_format": "nameIdFormat",
    "name_id_policy_format": "nameIdPolicyFormat",
    "not_before": "notBefore",
    "not_on_or_after": "notOnOrAfter",
    "offline_session_idle_timeout": "offlineSessionIdleTimeout",
    "offline_session_max_lifespan": "offlineSessionMaxLifespan",
    "offline_session_max_lifespan_enabled": "offlineSessionMaxLifespanEnabled",
    "optional_scopes": "optionalScopes",
    "owner_managed_access": "ownerManagedAccess",
    "parent_flow_alias": "parentFlowAlias",
    "parent_id": "parentId",
    "password_policy": "passwordPolicy",
    "pkce_code_challenge_method": "pkceCodeChallengeMethod",
    "policy_id": "policyId",
    "policy_type": "policyType",
    "post_binding_authn_request": "postBindingAuthnRequest",
    "post_binding_logout": "postBindingLogout",
    "post_binding_response": "postBindingResponse",
    "post_broker_login_flow_alias": "postBrokerLoginFlowAlias",
    "preserve_group_inheritance": "preserveGroupInheritance",
    "protocol_mapper": "protocolMapper",
    "provider_alias": "providerAlias",
    "provider_id": "providerId",
    "rdn_ldap_attribute": "rdnLdapAttribute",
    "read_only": "readOnly",
    "read_timeout": "readTimeout",
    "realm_id": "realmId",
    "realm_role_prefix": "realmRolePrefix",
    "refresh_token_max_reuse": "refreshTokenMaxReuse",
    "registration_allowed": "registrationAllowed",
    "registration_email_as_username": "registrationEmailAsUsername",
    "registration_flow": "registrationFlow",
    "remember_me": "rememberMe",
    "request_refresh_token": "requestRefreshToken",
    "reset_credentials_flow": "resetCredentialsFlow",
    "reset_password_allowed": "resetPasswordAllowed",
    "resource_server_id": "resourceServerId",
    "revoke_refresh_token": "revokeRefreshToken",
    "role_id": "roleId",
    "role_ids": "roleIds",
    "role_name_ldap_attribute": "roleNameLdapAttribute",
    "role_object_classes": "roleObjectClasses",
    "roles_ldap_filter": "rolesLdapFilter",
    "root_ca_certificate": "rootCaCertificate",
    "root_url": "rootUrl",
    "saml_attribute_name": "samlAttributeName",
    "saml_attribute_name_format": "samlAttributeNameFormat",
    "search_scope": "searchScope",
    "security_defenses": "securityDefenses",
    "service_account_user_id": "serviceAccountUserId",
    "service_accounts_enabled": "serviceAccountsEnabled",
    "session_note": "sessionNote",
    "session_note_label": "sessionNoteLabel",
    "sign_assertions": "signAssertions",
    "sign_documents": "signDocuments",
    "signature_algorithm": "signatureAlgorithm",
    "signing_certificate": "signingCertificate",
    "signing_private_key": "signingPrivateKey",
    "single_logout_service_url": "singleLogoutServiceUrl",
    "single_sign_on_service_url": "singleSignOnServiceUrl",
    "smtp_server": "smtpServer",
    "ssl_required": "sslRequired",
    "sso_session_idle_timeout": "ssoSessionIdleTimeout",
    "sso_session_idle_timeout_remember_me": "ssoSessionIdleTimeoutRememberMe",
    "sso_session_max_lifespan": "ssoSessionMaxLifespan",
    "sso_session_max_lifespan_remember_me": "ssoSessionMaxLifespanRememberMe",
    "standard_flow_enabled": "standardFlowEnabled",
    "store_token": "storeToken",
    "sync_registrations": "syncRegistrations",
    "tls_insecure_skip_verify": "tlsInsecureSkipVerify",
    "token_exchange_scope": "tokenExchangeScope",
    "token_url": "tokenUrl",
    "trust_email": "trustEmail",
    "ui_locales": "uiLocales",
    "use_realm_roles_mapping": "useRealmRolesMapping",
    "use_truststore_spi": "useTruststoreSpi",
    "use_user_ip_param": "useUserIpParam",
    "user_attribute": "userAttribute",
    "user_id": "userId",
    "user_impersonated_scope": "userImpersonatedScope",
    "user_info_url": "userInfoUrl",
    "user_managed_access": "userManagedAccess",
    "user_model_attribute": "userModelAttribute",
    "user_object_classes": "userObjectClasses",
    "user_property": "userProperty",
    "user_roles_retrieve_strategy": "userRolesRetrieveStrategy",
    "user_session": "userSession",
    "username_ldap_attribute": "usernameLdapAttribute",
    "users_dn": "usersDn",
    "uuid_ldap_attribute": "uuidLdapAttribute",
    "valid_redirect_uris": "validRedirectUris",
    "validate_password_policy": "validatePasswordPolicy",
    "validate_signature": "validateSignature",
    "verify_email": "verifyEmail",
    "view_scope": "viewScope",
    "want_assertions_encrypted": "wantAssertionsEncrypted",
    "want_assertions_signed": "wantAssertionsSigned",
    "web_authn_passwordless_policy": "webAuthnPasswordlessPolicy",
    "web_authn_policy": "webAuthnPolicy",
    "web_origins": "webOrigins",
    "write_only": "writeOnly",
    "xml_sign_key_info_key_name_transformer": "xmlSignKeyInfoKeyNameTransformer",
    "year_end": "yearEnd",
}

CAMEL_TO_SNAKE_CASE_TABLE = {
    "acceptsPromptNoneForwardFromClient": "accepts_prompt_none_forward_from_client",
    "accessCodeLifespan": "access_code_lifespan",
    "accessCodeLifespanLogin": "access_code_lifespan_login",
    "accessCodeLifespanUserAction": "access_code_lifespan_user_action",
    "accessTokenLifespan": "access_token_lifespan",
    "accessTokenLifespanForImplicitFlow": "access_token_lifespan_for_implicit_flow",
    "accessType": "access_type",
    "accountTheme": "account_theme",
    "actionTokenGeneratedByAdminLifespan": "action_token_generated_by_admin_lifespan",
    "actionTokenGeneratedByUserLifespan": "action_token_generated_by_user_lifespan",
    "addReadTokenRoleOnCreate": "add_read_token_role_on_create",
    "addToAccessToken": "add_to_access_token",
    "addToIdToken": "add_to_id_token",
    "addToUserinfo": "add_to_userinfo",
    "adminEventsDetailsEnabled": "admin_events_details_enabled",
    "adminEventsEnabled": "admin_events_enabled",
    "adminTheme": "admin_theme",
    "adminUrl": "admin_url",
    "aggregateAttributes": "aggregate_attributes",
    "alwaysReadValueFromLdap": "always_read_value_from_ldap",
    "assertionConsumerPostUrl": "assertion_consumer_post_url",
    "assertionConsumerRedirectUrl": "assertion_consumer_redirect_url",
    "attributeFriendlyName": "attribute_friendly_name",
    "attributeName": "attribute_name",
    "attributeValue": "attribute_value",
    "authenticateByDefault": "authenticate_by_default",
    "authenticationFlowBindingOverrides": "authentication_flow_binding_overrides",
    "authorizationIdpResourceId": "authorization_idp_resource_id",
    "authorizationResourceServerId": "authorization_resource_server_id",
    "authorizationTokenExchangeScopePermissionId": "authorization_token_exchange_scope_permission_id",
    "authorizationUrl": "authorization_url",
    "backchannelSupported": "backchannel_supported",
    "basePath": "base_path",
    "baseUrl": "base_url",
    "batchSizeForSync": "batch_size_for_sync",
    "bindCredential": "bind_credential",
    "bindDn": "bind_dn",
    "browserFlow": "browser_flow",
    "cachePolicy": "cache_policy",
    "changedSyncPeriod": "changed_sync_period",
    "claimName": "claim_name",
    "claimValue": "claim_value",
    "claimValueType": "claim_value_type",
    "clientAuthenticationFlow": "client_authentication_flow",
    "clientId": "client_id",
    "clientIdForRoleMappings": "client_id_for_role_mappings",
    "clientOfflineSessionIdleTimeout": "client_offline_session_idle_timeout",
    "clientOfflineSessionMaxLifespan": "client_offline_session_max_lifespan",
    "clientRolePrefix": "client_role_prefix",
    "clientScopeId": "client_scope_id",
    "clientSecret": "client_secret",
    "clientSessionIdleTimeout": "client_session_idle_timeout",
    "clientSessionMaxLifespan": "client_session_max_lifespan",
    "clientSignatureRequired": "client_signature_required",
    "clientTimeout": "client_timeout",
    "compositeRoles": "composite_roles",
    "configureScope": "configure_scope",
    "connectionTimeout": "connection_timeout",
    "connectionUrl": "connection_url",
    "consentRequired": "consent_required",
    "consentScreenText": "consent_screen_text",
    "customUserSearchFilter": "custom_user_search_filter",
    "dayMonth": "day_month",
    "dayMonthEnd": "day_month_end",
    "decisionStrategy": "decision_strategy",
    "defaultAction": "default_action",
    "defaultDefaultClientScopes": "default_default_client_scopes",
    "defaultOptionalClientScopes": "default_optional_client_scopes",
    "defaultScopes": "default_scopes",
    "defaultSignatureAlgorithm": "default_signature_algorithm",
    "directAccessGrantsEnabled": "direct_access_grants_enabled",
    "directGrantFlow": "direct_grant_flow",
    "disableUserInfo": "disable_user_info",
    "displayName": "display_name",
    "displayNameHtml": "display_name_html",
    "dockerAuthenticationFlow": "docker_authentication_flow",
    "dropNonExistingGroupsDuringSync": "drop_non_existing_groups_during_sync",
    "duplicateEmailsAllowed": "duplicate_emails_allowed",
    "editMode": "edit_mode",
    "editUsernameAllowed": "edit_username_allowed",
    "emailTheme": "email_theme",
    "emailVerified": "email_verified",
    "enabledEventTypes": "enabled_event_types",
    "encryptAssertions": "encrypt_assertions",
    "encryptionCertificate": "encryption_certificate",
    "eventsEnabled": "events_enabled",
    "eventsExpiration": "events_expiration",
    "eventsListeners": "events_listeners",
    "excludeSessionStateFromAuthResponse": "exclude_session_state_from_auth_response",
    "executionId": "execution_id",
    "extraConfig": "extra_config",
    "federatedIdentities": "federated_identities",
    "firstBrokerLoginFlowAlias": "first_broker_login_flow_alias",
    "firstName": "first_name",
    "forceAuthn": "force_authn",
    "forceNameIdFormat": "force_name_id_format",
    "forcePostBinding": "force_post_binding",
    "friendlyName": "friendly_name",
    "frontChannelLogout": "front_channel_logout",
    "fullPath": "full_path",
    "fullScopeAllowed": "full_scope_allowed",
    "fullSyncPeriod": "full_sync_period",
    "groupId": "group_id",
    "groupIds": "group_ids",
    "groupNameLdapAttribute": "group_name_ldap_attribute",
    "groupObjectClasses": "group_object_classes",
    "groupsClaim": "groups_claim",
    "groupsLdapFilter": "groups_ldap_filter",
    "groupsPath": "groups_path",
    "guiOrder": "gui_order",
    "hideOnLoginPage": "hide_on_login_page",
    "hostedDomain": "hosted_domain",
    "hourEnd": "hour_end",
    "iconUri": "icon_uri",
    "identityProviderAlias": "identity_provider_alias",
    "idpInitiatedSsoRelayState": "idp_initiated_sso_relay_state",
    "idpInitiatedSsoUrlName": "idp_initiated_sso_url_name",
    "ignoreMissingGroups": "ignore_missing_groups",
    "impersonateScope": "impersonate_scope",
    "implicitFlowEnabled": "implicit_flow_enabled",
    "importEnabled": "import_enabled",
    "includeAuthnStatement": "include_authn_statement",
    "includeInTokenScope": "include_in_token_scope",
    "includedClientAudience": "included_client_audience",
    "includedCustomAudience": "included_custom_audience",
    "initialLogin": "initial_login",
    "initialPassword": "initial_password",
    "internalId": "internal_id",
    "isMandatoryInLdap": "is_mandatory_in_ldap",
    "jwksUrl": "jwks_url",
    "lastName": "last_name",
    "ldapAttribute": "ldap_attribute",
    "ldapFullNameAttribute": "ldap_full_name_attribute",
    "ldapGroupsDn": "ldap_groups_dn",
    "ldapPasswordPolicyHintsEnabled": "ldap_password_policy_hints_enabled",
    "ldapRolesDn": "ldap_roles_dn",
    "ldapUserFederationId": "ldap_user_federation_id",
    "linkOnly": "link_only",
    "loginHint": "login_hint",
    "loginTheme": "login_theme",
    "loginWithEmailAllowed": "login_with_email_allowed",
    "logoutServicePostBindingUrl": "logout_service_post_binding_url",
    "logoutServiceRedirectBindingUrl": "logout_service_redirect_binding_url",
    "logoutUrl": "logout_url",
    "manageGroupMembershipScope": "manage_group_membership_scope",
    "manageScope": "manage_scope",
    "mapRolesClientScopeScope": "map_roles_client_scope_scope",
    "mapRolesCompositeScope": "map_roles_composite_scope",
    "mapRolesScope": "map_roles_scope",
    "mappedGroupAttributes": "mapped_group_attributes",
    "masterSamlProcessingUrl": "master_saml_processing_url",
    "memberofLdapAttribute": "memberof_ldap_attribute",
    "membershipAttributeType": "membership_attribute_type",
    "membershipLdapAttribute": "membership_ldap_attribute",
    "membershipUserLdapAttribute": "membership_user_ldap_attribute",
    "minuteEnd": "minute_end",
    "monthEnd": "month_end",
    "nameIdFormat": "name_id_format",
    "nameIdPolicyFormat": "name_id_policy_format",
    "notBefore": "not_before",
    "notOnOrAfter": "not_on_or_after",
    "offlineSessionIdleTimeout": "offline_session_idle_timeout",
    "offlineSessionMaxLifespan": "offline_session_max_lifespan",
    "offlineSessionMaxLifespanEnabled": "offline_session_max_lifespan_enabled",
    "optionalScopes": "optional_scopes",
    "ownerManagedAccess": "owner_managed_access",
    "parentFlowAlias": "parent_flow_alias",
    "parentId": "parent_id",
    "passwordPolicy": "password_policy",
    "pkceCodeChallengeMethod": "pkce_code_challenge_method",
    "policyId": "policy_id",
    "policyType": "policy_type",
    "postBindingAuthnRequest": "post_binding_authn_request",
    "postBindingLogout": "post_binding_logout",
    "postBindingResponse": "post_binding_response",
    "postBrokerLoginFlowAlias": "post_broker_login_flow_alias",
    "preserveGroupInheritance": "preserve_group_inheritance",
    "protocolMapper": "protocol_mapper",
    "providerAlias": "provider_alias",
    "providerId": "provider_id",
    "rdnLdapAttribute": "rdn_ldap_attribute",
    "readOnly": "read_only",
    "readTimeout": "read_timeout",
    "realmId": "realm_id",
    "realmRolePrefix": "realm_role_prefix",
    "refreshTokenMaxReuse": "refresh_token_max_reuse",
    "registrationAllowed": "registration_allowed",
    "registrationEmailAsUsername": "registration_email_as_username",
    "registrationFlow": "registration_flow",
    "rememberMe": "remember_me",
    "requestRefreshToken": "request_refresh_token",
    "resetCredentialsFlow": "reset_credentials_flow",
    "resetPasswordAllowed": "reset_password_allowed",
    "resourceServerId": "resource_server_id",
    "revokeRefreshToken": "revoke_refresh_token",
    "roleId": "role_id",
    "roleIds": "role_ids",
    "roleNameLdapAttribute": "role_name_ldap_attribute",
    "roleObjectClasses": "role_object_classes",
    "rolesLdapFilter": "roles_ldap_filter",
    "rootCaCertificate": "root_ca_certificate",
    "rootUrl": "root_url",
    "samlAttributeName": "saml_attribute_name",
    "samlAttributeNameFormat": "saml_attribute_name_format",
    "searchScope": "search_scope",
    "securityDefenses": "security_defenses",
    "serviceAccountUserId": "service_account_user_id",
    "serviceAccountsEnabled": "service_accounts_enabled",
    "sessionNote": "session_note",
    "sessionNoteLabel": "session_note_label",
    "signAssertions": "sign_assertions",
    "signDocuments": "sign_documents",
    "signatureAlgorithm": "signature_algorithm",
    "signingCertificate": "signing_certificate",
    "signingPrivateKey": "signing_private_key",
    "singleLogoutServiceUrl": "single_logout_service_url",
    "singleSignOnServiceUrl": "single_sign_on_service_url",
    "smtpServer": "smtp_server",
    "sslRequired": "ssl_required",
    "ssoSessionIdleTimeout": "sso_session_idle_timeout",
    "ssoSessionIdleTimeoutRememberMe": "sso_session_idle_timeout_remember_me",
    "ssoSessionMaxLifespan": "sso_session_max_lifespan",
    "ssoSessionMaxLifespanRememberMe": "sso_session_max_lifespan_remember_me",
    "standardFlowEnabled": "standard_flow_enabled",
    "storeToken": "store_token",
    "syncRegistrations": "sync_registrations",
    "tlsInsecureSkipVerify": "tls_insecure_skip_verify",
    "tokenExchangeScope": "token_exchange_scope",
    "tokenUrl": "token_url",
    "trustEmail": "trust_email",
    "uiLocales": "ui_locales",
    "useRealmRolesMapping": "use_realm_roles_mapping",
    "useTruststoreSpi": "use_truststore_spi",
    "useUserIpParam": "use_user_ip_param",
    "userAttribute": "user_attribute",
    "userId": "user_id",
    "userImpersonatedScope": "user_impersonated_scope",
    "userInfoUrl": "user_info_url",
    "userManagedAccess": "user_managed_access",
    "userModelAttribute": "user_model_attribute",
    "userObjectClasses": "user_object_classes",
    "userProperty": "user_property",
    "userRolesRetrieveStrategy": "user_roles_retrieve_strategy",
    "userSession": "user_session",
    "usernameLdapAttribute": "username_ldap_attribute",
    "usersDn": "users_dn",
    "uuidLdapAttribute": "uuid_ldap_attribute",
    "validRedirectUris": "valid_redirect_uris",
    "validatePasswordPolicy": "validate_password_policy",
    "validateSignature": "validate_signature",
    "verifyEmail": "verify_email",
    "viewScope": "view_scope",
    "wantAssertionsEncrypted": "want_assertions_encrypted",
    "wantAssertionsSigned": "want_assertions_signed",
    "webAuthnPasswordlessPolicy": "web_authn_passwordless_policy",
    "webAuthnPolicy": "web_authn_policy",
    "webOrigins": "web_origins",
    "writeOnly": "write_only",
    "xmlSignKeyInfoKeyNameTransformer": "xml_sign_key_info_key_name_transformer",
    "yearEnd": "year_end",
}
