# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union
from .. import _utilities, _tables

__all__ = ['ClientTimePolicy']


class ClientTimePolicy(pulumi.CustomResource):
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 day_month: Optional[pulumi.Input[str]] = None,
                 day_month_end: Optional[pulumi.Input[str]] = None,
                 decision_strategy: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 hour: Optional[pulumi.Input[str]] = None,
                 hour_end: Optional[pulumi.Input[str]] = None,
                 logic: Optional[pulumi.Input[str]] = None,
                 minute: Optional[pulumi.Input[str]] = None,
                 minute_end: Optional[pulumi.Input[str]] = None,
                 month: Optional[pulumi.Input[str]] = None,
                 month_end: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 not_before: Optional[pulumi.Input[str]] = None,
                 not_on_or_after: Optional[pulumi.Input[str]] = None,
                 realm_id: Optional[pulumi.Input[str]] = None,
                 resource_server_id: Optional[pulumi.Input[str]] = None,
                 year: Optional[pulumi.Input[str]] = None,
                 year_end: Optional[pulumi.Input[str]] = None,
                 __props__=None,
                 __name__=None,
                 __opts__=None):
        """
        Create a ClientTimePolicy resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = _utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['day_month'] = day_month
            __props__['day_month_end'] = day_month_end
            if decision_strategy is None and not opts.urn:
                raise TypeError("Missing required property 'decision_strategy'")
            __props__['decision_strategy'] = decision_strategy
            __props__['description'] = description
            __props__['hour'] = hour
            __props__['hour_end'] = hour_end
            __props__['logic'] = logic
            __props__['minute'] = minute
            __props__['minute_end'] = minute_end
            __props__['month'] = month
            __props__['month_end'] = month_end
            __props__['name'] = name
            __props__['not_before'] = not_before
            __props__['not_on_or_after'] = not_on_or_after
            if realm_id is None and not opts.urn:
                raise TypeError("Missing required property 'realm_id'")
            __props__['realm_id'] = realm_id
            if resource_server_id is None and not opts.urn:
                raise TypeError("Missing required property 'resource_server_id'")
            __props__['resource_server_id'] = resource_server_id
            __props__['year'] = year
            __props__['year_end'] = year_end
        super(ClientTimePolicy, __self__).__init__(
            'keycloak:openid/clientTimePolicy:ClientTimePolicy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            day_month: Optional[pulumi.Input[str]] = None,
            day_month_end: Optional[pulumi.Input[str]] = None,
            decision_strategy: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            hour: Optional[pulumi.Input[str]] = None,
            hour_end: Optional[pulumi.Input[str]] = None,
            logic: Optional[pulumi.Input[str]] = None,
            minute: Optional[pulumi.Input[str]] = None,
            minute_end: Optional[pulumi.Input[str]] = None,
            month: Optional[pulumi.Input[str]] = None,
            month_end: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            not_before: Optional[pulumi.Input[str]] = None,
            not_on_or_after: Optional[pulumi.Input[str]] = None,
            realm_id: Optional[pulumi.Input[str]] = None,
            resource_server_id: Optional[pulumi.Input[str]] = None,
            year: Optional[pulumi.Input[str]] = None,
            year_end: Optional[pulumi.Input[str]] = None) -> 'ClientTimePolicy':
        """
        Get an existing ClientTimePolicy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["day_month"] = day_month
        __props__["day_month_end"] = day_month_end
        __props__["decision_strategy"] = decision_strategy
        __props__["description"] = description
        __props__["hour"] = hour
        __props__["hour_end"] = hour_end
        __props__["logic"] = logic
        __props__["minute"] = minute
        __props__["minute_end"] = minute_end
        __props__["month"] = month
        __props__["month_end"] = month_end
        __props__["name"] = name
        __props__["not_before"] = not_before
        __props__["not_on_or_after"] = not_on_or_after
        __props__["realm_id"] = realm_id
        __props__["resource_server_id"] = resource_server_id
        __props__["year"] = year
        __props__["year_end"] = year_end
        return ClientTimePolicy(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="dayMonth")
    def day_month(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "day_month")

    @property
    @pulumi.getter(name="dayMonthEnd")
    def day_month_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "day_month_end")

    @property
    @pulumi.getter(name="decisionStrategy")
    def decision_strategy(self) -> pulumi.Output[str]:
        return pulumi.get(self, "decision_strategy")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def hour(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "hour")

    @property
    @pulumi.getter(name="hourEnd")
    def hour_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "hour_end")

    @property
    @pulumi.getter
    def logic(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "logic")

    @property
    @pulumi.getter
    def minute(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "minute")

    @property
    @pulumi.getter(name="minuteEnd")
    def minute_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "minute_end")

    @property
    @pulumi.getter
    def month(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "month")

    @property
    @pulumi.getter(name="monthEnd")
    def month_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "month_end")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="notBefore")
    def not_before(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "not_before")

    @property
    @pulumi.getter(name="notOnOrAfter")
    def not_on_or_after(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "not_on_or_after")

    @property
    @pulumi.getter(name="realmId")
    def realm_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "realm_id")

    @property
    @pulumi.getter(name="resourceServerId")
    def resource_server_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "resource_server_id")

    @property
    @pulumi.getter
    def year(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "year")

    @property
    @pulumi.getter(name="yearEnd")
    def year_end(self) -> pulumi.Output[Optional[str]]:
        return pulumi.get(self, "year_end")

    def translate_output_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return _tables.SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

